#####################
Constraints Functions
#####################

This module have functions that help us to create any kind of linear constraint
related to the assets or assets class weights or related to the value of the sensitivity
of the portfolio to a specific risk factor. These functions transform all
constraint to the form :math:`Aw \geq B`.

Also this module have a function that help us to create relative and absolute views for the Black Litterman model. This views can consider relationships among assets and asset classes. This function transform all views to the form :math:`Pw = Q`.


Module Functions
================

.. automodule:: ConstraintsFunctions
   :members:
   :private-members:
